﻿using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Net;
using System.IO;
using System.Collections.Specialized;


namespace TLEData
{
    public class TleFile
    {
        //Name
        protected string satName;

        //Line1
        protected int satNum1;
        protected char classification;
        protected int IdLaunchYear;
        protected int IdLauchDate;
        protected string IdPiece;
        protected int epochYear;
        protected double epochDay;
        protected double firstDerMeanMotion;
        protected double secondDerMeanMotion;
        protected double dragTerm;
        protected double ephemeris;
        protected int elementNum;
        protected int checkSum1;

        //Line2
        protected int satNum2;
        protected double inclination;
        protected double rightAscension;
        protected double eccentricity;
        protected double augmentPedigree;
        protected double meanAnomoly;
        protected double meanMotion;
        protected double revolutionNum;
        protected int checkSum2;




        
        public TleFile(string _satName, int _satNum1, char _classification, int _IdLaunchYear, int _IdLauchDate, string _IdPiece, int _epochYear, double _epochDay, double _firstDerMeanMotion, double _secondDerMeanMotion,
                       double _dragTerm, double _ephemeris, int _elementNum, int _checkSum1, int _satNum2, double _inclination, double _rightAscension, double _eccentricity, double _augmentPedigree,
                       double _meanAnomoly, double _meanMotion, double _revolutionNum, int _checkSum2)        
        {
            satName = _satName;
            satNum1 = _satNum1;
            classification = _classification;
            IdLaunchYear = _IdLaunchYear;
            IdLauchDate = _IdLauchDate;
            IdPiece = _IdPiece;
            epochYear = _epochYear;
            epochDay = _epochDay;
            firstDerMeanMotion = _firstDerMeanMotion;
            secondDerMeanMotion = _secondDerMeanMotion;
            dragTerm = _dragTerm;
            ephemeris = _ephemeris;
            elementNum = _elementNum;
            checkSum1 = _checkSum1;
            satNum2 = _satNum2;
            inclination = _inclination;
            rightAscension = _rightAscension;
            eccentricity = _eccentricity;
            augmentPedigree = _augmentPedigree;
            meanAnomoly = _meanAnomoly;
            meanMotion = _meanMotion;
            revolutionNum = _revolutionNum;
            checkSum2 = _checkSum2;
        }

        /***CODE BELOW IS MODIFIED FROM SGP4 MODEL NUGET***/
        /***Variable names are changed to reflect our variables***/

        //! Returns true if Data matches Checksum
        /*!
        \return boolean true/false
        */
        public bool isValidData()
        {
            return true;
        }

        //! Returns the Object Name
        /*!
        \return string Name
        */
        public string getName()
        {
            return satName;
        }

        //! Returns the NORAD Identification
        /*!
        \return string NoradID
        */
        public string getNoradID()
        {
            return satNum1.ToString();
        }

        //! Returns the start Year of satellite
        /*!
        \returns int StartYear
        */
        public int getStartYear()
        {
            return IdLaunchYear;
        }

        //! Returns the start number of satellite
        /*!
        \returns int StartNumber
        */
        public int getStartNr()
        {
            return IdLauchDate;
        }

        //! Returns the Piece designator
        /*!
        \returns string Piece
        */
        public string getPice()
        {
            return IdPiece;
        }

        //! Returns the Year of the Epoch
        /*!
        \returns int EpochYear
        */
        public int getEpochYear()
        {
            return epochYear;
        }

        //! Returns the Day of the Epoch
        /*!
        \returns double EpochDay
        */
        public double getEpochDay()
        {
            return epochDay;
        }

        //! Returns the First Mean Motion
        /*!
        \returns double meanMotion
        */
        public double getFirstMeanMotion()
        {
            return firstDerMeanMotion;
        }

        //! Returns the Second Mean Motion
        /*!
        \returns double secondMeanMotion
        */
        public double getSecondMeanMotion()
        {
            return secondDerMeanMotion;
        }

        //! Returns the Drag value
        /*!
        \returns double dragTerm
        */
        public double getDrag()
        {
            return dragTerm;
        }

        //! Returns the Ephemeris
        /*!
        \returns double ephemeris
        */
        public double getEphemeris()
        {
            return ephemeris;
        }

        //! Returns the Set Number
        /*!
        \returns double setNumber
        */
        public double getSetNumber()
        {
            return elementNum;
        }

        //! Returns the Satellite Number
        /*!
        \returns int satNumber
        */
        public int getSatNumber()
        {
            return satNum2;
        }

        //! Returns the Inclination 
        /*!
        \returns double inclination
        */
        public double getInclination()
        {
            return inclination;
        }

        //! Returns the Richt Ascending Node
        /*!
        \returns double right Ascension
        */
        public double getRightAscendingNode()
        {
            return rightAscension;
        }

        //! Returns the Eccentricity
        /*!
        \returns double eccentricity
        */
        public double getEccentriciy()
        {
            return eccentricity;
        }

        //! Returns the Perigee
        /*!
        \returns double perigee
        */
        public double getPerigee()
        {
            return augmentPedigree;
        }

        //! Returns the Mean Anomoly 
        /*!
        \returns double meanAnomoly
        */
        public double getMeanAnomoly()
        {
            return meanAnomoly;
        }

        //! Returns the Mean Motion
        /*!
        \returns double meanMotion
        */
        public double getMeanMotion()
        {
            return meanMotion;
        }

        //! Returns the number of Relevations
        /*!
        \returns double relevationNumber
        */
        public double getRelevationNumber()
        {
            return revolutionNum;
        }

        //! Returns Classification
        /*!
        \returns ing satellite Classifictaion
        */
        public int getClassification()
        {
            return (int)classification;
        }

        //! Returns the Checksum for the first TLE line
        /*!
        \returns int checksum1
        */
        public int getFirstCheckSum()
        {
            return checkSum1;
        }

        //! Returns the Checksum for the second TLE line
        /*!
        \returns int checksum2
        */
        public int getSecCheckSum()
        {
            return checkSum2;
        }
    }
}
